==> huaweicloudsdkcce-3.1.134-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/upgrade_work_flow_update_request_body_status.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpgradeWorkFlowUpdateRequestBodyStatus:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'phase': 'WorkFlowPhase'
    }

    attribute_map = {
        'phase': 'phase'
    }

    def __init__(self, phase=None):
        """UpgradeWorkFlowUpdateRequestBodyStatus

        The model defined in huaweicloud sdk

        :param phase: 
        :type phase: :class:`huaweicloudsdkcce.v3.WorkFlowPhase`
        """
        
        

        self._phase = None
        self.discriminator = None

        if phase is not None:
            self.phase = phase

    @property
    def phase(self):
        """Gets the phase of this UpgradeWorkFlowUpdateRequestBodyStatus.

        :return: The phase of this UpgradeWorkFlowUpdateRequestBodyStatus.
        :rtype: :class:`huaweicloudsdkcce.v3.WorkFlowPhase`
        """
        return self._phase

    @phase.setter
    def phase(self, phase):
        """Sets the phase of this UpgradeWorkFlowUpdateRequestBodyStatus.

        :param phase: The phase of this UpgradeWorkFlowUpdateRequestBodyStatus.
        :type phase: :class:`huaweicloudsdkcce.v3.WorkFlowPhase`
        """
        self._phase = phase

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeWorkFlowUpdateRequestBodyStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other

==> huaweicloudsdkcce-3.1.151-py2.py3-none-any.whl: huaweicloudsdkcce/v3/model/upgrade_work_flow_update_request_body_status.py <==
# coding: utf-8

import six

from huaweicloudsdkcore.utils.http_utils import sanitize_for_serialization


class UpgradeWorkFlowUpdateRequestBodyStatus:

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    sensitive_list = []

    openapi_types = {
        'phase': 'WorkFlowPhase'
    }

    attribute_map = {
        'phase': 'phase'
    }

    def __init__(self, phase=None):
        r"""UpgradeWorkFlowUpdateRequestBodyStatus

        The model defined in huaweicloud sdk

        :param phase: 
        :type phase: :class:`huaweicloudsdkcce.v3.WorkFlowPhase`
        """
        
        

        self._phase = None
        self.discriminator = None

        if phase is not None:
            self.phase = phase

    @property
    def phase(self):
        r"""Gets the phase of this UpgradeWorkFlowUpdateRequestBodyStatus.

        :return: The phase of this UpgradeWorkFlowUpdateRequestBodyStatus.
        :rtype: :class:`huaweicloudsdkcce.v3.WorkFlowPhase`
        """
        return self._phase

    @phase.setter
    def phase(self, phase):
        r"""Sets the phase of this UpgradeWorkFlowUpdateRequestBodyStatus.

        :param phase: The phase of this UpgradeWorkFlowUpdateRequestBodyStatus.
        :type phase: :class:`huaweicloudsdkcce.v3.WorkFlowPhase`
        """
        self._phase = phase

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                if attr in self.sensitive_list:
                    result[attr] = "****"
                else:
                    result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        import simplejson as json
        if six.PY2:
            import sys
            reload(sys)
            sys.setdefaultencoding("utf-8")
        return json.dumps(sanitize_for_serialization(self), ensure_ascii=False)

    def __repr__(self):
        """For `print`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UpgradeWorkFlowUpdateRequestBodyStatus):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other
